<?php
/**
 * Librera para que aplicaciones PHP/GVHidra puedan acceder al Web Service de Autorizacion (autorizacionArangi)
 *
 * @package		WSClientAutoriza
 * @author 		David Pascual <pascual_dav@externosgva.es>
 * @version		Release: @package_version@
 * @copyright 	Copyright (C) 2015 Generalitat Valenciana.
 * @license 	http://opensource.org/licenses/gpl-2.0.php GNU Public License v2.0
 * @link 		https://gvhidra.gva.es/redmine/projects/wscomun
 */

use WSCOMUN\WSComunFClient;

class WSClientAutoriza extends WSComunFClient
{

	/**
	 * Devuelve una matriz de arrays asociativos [idGrupo | permiso], las autorizaciones que posee el ususario para esa aplicacin.
	 *
	 * Los WS invocados pertenecen al servicio deAutorizacin) (autorizacionArangi v1.00).
	 * @subpackage 	Autorizacion
	 * @param  	string	$usuarioHDFI	Usuario HDFI
	 * @param  	string	$idAplicacion	Cdigo de la aplicacin
	 * @return 	array	Matriz de arrays asociativo [idGrupo]|[permisos]
	 * @access 	public
	 */
	public function retornaAutorizacionWS ($usuarioHDFI, $idAplicacion)
	{
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_AUTORIZA);
			$clienteWS = $this->v_clienteWS[self::KEYCLIENTE_AUTORIZA];

			$retornaAutorizacionWS = new ArrayObject();
			$retornaAutorizacionWS->append(new SoapVar($usuarioHDFI,XSD_STRING,null,null,'usuarioHDFI', self::$NAMESPACE_GVA));
			$retornaAutorizacionWS->append(new SoapVar($idAplicacion,XSD_STRING,null,null,'idAplicacion', self::$NAMESPACE_GVA));
			$miSoapRQ = new SoapVar($retornaAutorizacionWS, SOAP_ENC_OBJECT,null,null,'retornaAutorizacionWSRequest', self::$NAMESPACE_GVA);

			$lista = $clienteWS->retornaAutorizacionWS($miSoapRQ);

			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
			}

		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
				throw $e;
			}
			else throw $e;
		}

		//Tratamos la informacin obtenida del WS
		try
		{
			if (!is_object($lista))
			{
				if ($this->getDebugMode())
				{
					$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
					$this->addDebugInfo("\nLista de autorizaciones vaca\n");
				}
				else
					return array();
			}

			$vLista = array();
			foreach ($lista->permisoapp as $objeto)
			{
				$vLista[] = array
				(
						'nif' => $objeto->nif,
						'usrTipo' => $objeto->usrtipo,
						'idGrupo'=> $objeto->idgrupo,
						'idRol' => $objeto->idrol,
						'idAplicacion'=>$objeto->idaplicacion
				);
			}

			return $vLista;

		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'.'. Error en el tratmineo del objeto lista');
			}
		}
	}//retornaAutorizacionWS


	/**
	 * Devuelve una matriz de arrays asociativos [usrCodigo|usrTipo|idGrupo|idRol] con las autorizaciones de  un ususario. (Subpaquete Autorizacin)
	 *
	 * Los WS invocados pertenecen al servicio de Autorizacin (autorizacionArangi v1.00).
	 * @subpackage 	Autorizacion
	 * @param  	string	$usuarioHDFI	Usuario HDFI
	 * @return 	array	$resultado		Vector asociativo con grupos y roles del ususairo en la aplicacin o null si error de autenticacin
	 * @access 	public
	 */
	public function retornaTodasAutorizacionesWS ($usuarioHDFI)
	{
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_AUTORIZA);
			$clienteWS = $this->v_clienteWS[self::KEYCLIENTE_AUTORIZA];

			$retornaTodasAutorizacionesWS = new ArrayObject();
			$retornaTodasAutorizacionesWS->append(new SoapVar($usuarioHDFI,XSD_STRING,null,null,'usuarioHDFI', self::$NAMESPACE_GVA));

			$miSoapRQ = new SoapVar($retornaTodasAutorizacionesWS, SOAP_ENC_OBJECT,null,null,'retornaTodasAutorizacionesWSRequest', self::$NAMESPACE_GVA);

			$lista = $clienteWS->retornaTodasAutorizacionesWS($miSoapRQ);

			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
			}

		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
				throw $e;
			}
			else throw $e;
		}

		//Tratamos la informacin obtenida del WS
		try
		{

			if (!is_object($lista))
			{
				if ($this->getDebugMode())
				{
					$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
					$this->addDebugInfo("\nLista de autorizaciones vaca\n");
				}
				else
					return array();
			}

			/*
			 [usrcodigo] => 37178
			 [usrtipo] => U
			 [idgrupo] => 380
			 [idrol] =>
			 */
			$vLista = array();

			//Devuelve un array de objetos, o un slo objeto. Si es array...
			if (is_array($lista->lista_permisos)) foreach ($lista->lista_permisos as $objeto)
			{
				$vLista[] = array(
						'usrCodigo'=> $objeto->usrcodigo,
						'usrTipo'=>$objeto->usrtipo,
						'idGrupo'=>$objeto->idgrupo,
						'idRol'=>$objeto->idrol
				);
			}
			else //Si es un slo registro
				$vLista[] = array(
						'usrCodigo'=> $lista->lista_permisos->usrcodigo,
						'usrTipo'=>$lista->lista_permisos->usrtipo,
						'idGrupo'=>$lista->lista_permisos->idgrupo,
						'idRol'=>$lista->lista_permisos->idrol
				);

				return $vLista;
		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'.'. Error en el tratmineo del objeto lista');
			}
		}
	}//Fin retornaTodasAutorizacionesWS



	/**
	 * Devuelve una matriz de arrays asociativos [idGrupo|permiso], las autorizaciones que posee el usuario para esa aplicacin.
	 *
	 * Los WS invocados pertenecen al servicio deAutorizacin) (autorizacionArangi v1.00).
	 * @subpackage 	Autorizacion
	 * @param  	string	$usuarioDNI	DNI del usuario
	 * @param  	string	$tipoBusqueda	[USUARIO|GRUPO]
	 * @return 	array	Matriz de arrays asociativo [usrCodigo][usrTipo][idGrupo][idRol]
	 * @access 	public
	 */
	public function retornaTodasAutorizacionesDNIWS ($usuarioDNI, $tipoBusqueda)
	{
		$lista = null;
		try
		{
			$this->__clienteOn(self::KEYCLIENTE_AUTORIZA);
			$clienteWS = $this->v_clienteWS[self::KEYCLIENTE_AUTORIZA];

			$retornaTodasAutorizacionesDNIWS = new ArrayObject();
			$retornaTodasAutorizacionesDNIWS->append(new SoapVar($usuarioDNI,XSD_STRING,null,null,'usuarioDNI', self::$NAMESPACE_GVA));
			$retornaTodasAutorizacionesDNIWS->append(new SoapVar($tipoBusqueda,XSD_STRING,null,null,'tipoBusqueda', self::$NAMESPACE_GVA));
			$miSoapRQ = new SoapVar($retornaTodasAutorizacionesDNIWS, SOAP_ENC_OBJECT,null,null,'retornaTodasAutorizacionesDNIWSRequest', self::$NAMESPACE_GVA);

			$lista = $clienteWS->retornaTodasAutorizacionesDNIWS($miSoapRQ);

			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
			}
		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
				if (is_object($clienteWS))
				{
					$this->addDebugInfo("RqH:\n ".$clienteWS->__getLastRequestHeaders());
					$this->addDebugInfo("Rq:\n ".$clienteWS->__getLastRequest());
					$this->addDebugInfo("RsH:\n ".$clienteWS->__getLastResponse());
					$this->addDebugInfo("Rs:\n ".$clienteWS->__getLastResponseHeaders());
				}
				throw $e;
			}
			else throw $e;
		}

		//Tratamos la informacin obtenida del WS
		try
		{
			if (!is_object($lista))
			{
				if ($this->getDebugMode())
				{
					$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'."\n");
					$this->addDebugInfo("\nLista de autorizaciones vaca\n");
				}
				else
					return array();
			}

			$vLista = array();

			//Devuelve un array de objetos, o un slo objeto. Si es array...
			if (is_array($lista->lista)) foreach ($lista->lista as $objeto)
			{
				$vLista[] = array(
						'usrCodigo'=> $objeto->usrcodigo,
						'usrTipo'=>$objeto->usrtipo,
						'idGrupo'=>$objeto->idgrupo,
						'idRol'=>$objeto->idrol
				);
			}
			else //Si es un slo registro
				$vLista[] = array(
						'usrCodigo'=> $lista->lista->usrcodigo,
						'usrTipo'=>$lista->lista->usrtipo,
						'idGrupo'=>$lista->lista->idgrupo,
						'idRol'=>$lista->lista->idrol
				);

				return $vLista;

		}
		catch (Exception $e)
		{
			if ($this->getDebugMode())
			{
				$this->addDebugInfo(__CLASS__.':'.__METHOD__.'['.__FILE__.'-'.__LINE__.']'.'. Error en el tratamiento del objeto lista');
			}
		}
	}//retornaTodasAutorizacionesDNIWS

}


?>